﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using System.ComponentModel;
using Infragistics.Controls.Charts;

namespace SeriesAddingWithCommand
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }
    }

    
    public class SelectedItemsToSeiresConverter : IMultiValueConverter
    {
        private bool AddAxisOnceOnly = false;
        CategoryXAxis xAxis  = new CategoryXAxis
        {
            Name = "SharedXAxis",
            Label = "{}{hh:mm:ss}",
            
            ItemsSource = "{Binding}",
            

            LabelSettings = new AxisLabelSettings() { Location = AxisLabelsLocation.OutsideBottom }
            
        };

        NumericYAxis yAxis = new NumericYAxis
        {
            Label = "{0:N2}",
            LabelSettings = new AxisLabelSettings() { Location = AxisLabelsLocation.OutsideLeft }
        };

        public object Convert(object[] values, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            XamDataChart chart = values[0] as XamDataChart;

            foreach (Series series in chart.Series)
            {
                series.Visibility = Visibility.Collapsed;
                (series as LineSeries).YAxis.LabelSettings.Visibility = Visibility.Collapsed;
                //(series as ScatterBase).YAxis.LabelSettings.Visibility = Visibility.Collapsed;
            }

            foreach (var item in values[1] as IList<object>)
            {
                if (chart.Series.Where(s => s.DataContext == item).FirstOrDefault() == null)
                {
                   

                    


                    //ScatterLineSeries series = new ScatterLineSeries
                    //{
                    //    XMemberPath = "DoubleDate",
                    //    YMemberPath = "Value1",
                    //    MarkerType = MarkerType.None,
                    //};
                    LineSeries series = new LineSeries();
                    series.MarkerType = MarkerType.None;

                    series.ValueMemberPath = "Value1";


                    series.SetBinding(LineSeries.XAxisProperty, new Binding { Source = xAxis });
                    series.SetBinding(LineSeries.YAxisProperty, new Binding { Source = yAxis });
                    series.SetBinding(LineSeries.DataContextProperty, new Binding { Source = item });
                    series.SetBinding(LineSeries.ItemsSourceProperty, new Binding { Path = new PropertyPath("ChartData") });
                    
                    //series.SetBinding(ScatterLineSeries.XAxisProperty, new Binding { Source = chart.Axes.FirstOrDefault() });
                    //series.SetBinding(ScatterLineSeries.YAxisProperty, new Binding { Source = yAxis });
                    //series.SetBinding(ScatterLineSeries.DataContextProperty, new Binding { Source = item });
                    //series.SetBinding(ScatterLineSeries.ItemsSourceProperty, new Binding { Path = new PropertyPath("ChartData") });
                    
        
                    if(!AddAxisOnceOnly)
                    {
                        chart.Axes.Add(yAxis);
                        chart.Axes.Add(xAxis);
                        AddAxisOnceOnly = false;
                    }
                   
                    chart.Series.Add(series);
                }
                else
                {
                    (chart.Series.Where(s => s.DataContext == item).FirstOrDefault() as LineSeries).Visibility = Visibility.Visible;
                    (chart.Series.Where(s => s.DataContext == item).FirstOrDefault() as LineSeries).YAxis.LabelSettings.Visibility = Visibility.Visible;
                    //(chart.Series.Where(s => s.DataContext == item).FirstOrDefault() as ScatterBase).Visibility = Visibility.Visible;
                    //(chart.Series.Where(s => s.DataContext == item).FirstOrDefault() as ScatterBase).YAxis.LabelSettings.Visibility = Visibility.Visible;
                }
            }
            return null;
        }

        public object[] ConvertBack(object value, Type[] targetTypes, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }

    public class MainWindowViewModel : PropertyChangedNotifier
    {
        private ObservableCollection<ChannelViewModel> channals;

        public MainWindowViewModel()
        {
            Channals = new ObservableCollection<ChannelViewModel>();
            Random r = new Random();
            for (int i = 0; i < 5; i++)
            {
                Channals.Add(new ChannelViewModel
                {
                    ChannalName = "Channal " + i,
                    ChartData = ChartDataViewModel.GenerateData(10000, r.Next(1,1000), r.Next(1001, 10000))
                    //ChartData = ChartDataViewModel.GenerateData(1000, 1+i, 1000+i)
                });
            }
        }

        public ObservableCollection<ChannelViewModel> Channals
        {
            get { return channals; }
            set { channals = value; OnPropertyChagned("Channals"); }
        }
        
    }

    public class ChannelViewModel : PropertyChangedNotifier
    {
        private string channalName;

        public string ChannalName
        {
            get { return channalName; }
            set { channalName = value; OnPropertyChagned("ChannalName"); }
        }


        private ObservableCollection<ChartDataViewModel> chartData;

        public ObservableCollection<ChartDataViewModel> ChartData
        {
            get { return chartData; }
            set { chartData = value; OnPropertyChagned("ChartData"); }
        }

    }

    public class ChartDataViewModel : PropertyChangedNotifier
    {
        private DateTime date;

        public DateTime MyDate
        {
            get { return date; }
            set { date = value; OnPropertyChagned("MyDate"); }
        }

        //public DateTime DoubleDate
        //{
        //    get { return DateTime.Now; }
        //}

        private double val1;

        public double Value1
        {
            get { return val1; }
            set { val1 = value; OnPropertyChagned("Value1"); }
        }


        public static ObservableCollection<ChartDataViewModel> GenerateData(int count, int startMin, int startMax)
        {
            ObservableCollection<ChartDataViewModel> data = new ObservableCollection<ChartDataViewModel>();

            Random r = new Random();

            ChartDataViewModel data0 = new ChartDataViewModel
            {
                MyDate = DateTime.Now.AddMinutes(1),
                Value1 = r.Next(startMin, startMax),
            };

            data.Add(data0);

            for (int i = 1; i < count; i++)
            {
                ChartDataViewModel dat = new ChartDataViewModel
                {
                    MyDate = DateTime.Now.AddMinutes(1 * i),
                };

                if (r.NextDouble() > .5)
                {
                    dat.Value1 = data[i - 1].Value1 + r.NextDouble();
                }
                else
                {
                    dat.Value1 = data[i - 1].Value1 - r.NextDouble();
                }

                data.Add(dat);
            }

            return data;
        }
    }

    public class PropertyChangedNotifier : INotifyPropertyChanged
    {
        public event PropertyChangedEventHandler PropertyChanged;

        public void OnPropertyChagned(string name)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(name));
        }
    }
}
